# =====================================
# generator=datazen
# version=3.1.3
# hash=53cc8b7e493e41d0b418c9a9b539c424
# =====================================

"""
Useful defaults and other package metadata.
"""

DESCRIPTION = "A framework for implementing Python services."
PKG_NAME = "runtimepy"
VERSION = "2.9.1"

# runtimepy-specific content.
METRICS_NAME = "metrics"
